OC.L10N.register(
    "news",
    {
    "Request failed, network connection unavailable!" : "Eskariak huts egin du, sare konexioa ez dago eskuragarri!",
    "Can not add feed: Exists already" : "Ezin da iturburua gehitu: Dagoeneko existitzen da",
    "Articles without feed" : "Iturbururik gabeko artikuluak",
    "Can not add folder: Exists already" : "Ezin da karpeta gehitu: Dagoeneko existitzen da",
    "News" : "Berriak",
    "An RSS/Atom feed reader" : "RSS/Atom jarioen irakurle bat",
    "Disable this if you run a custom updater such as the Python updater included in the app" : "Ezgaitu aplikazioarekin banatzen den Python eguneratzailea bezalako beste eguneratzaileren bat erabiltzen baduzu",
    "Saved" : "Gordeta",
    "Download" : "Deskargatu",
    "Close" : "Itxi",
    "Language" : "Hizkuntza",
    "Subscribe" : "Harpidetu",
    "Open website" : "Ireki webgunea",
    "Star article" : "Izarra artikuluari",
    "Unstar article" : "Kendu izarra artikuluari",
    "Keep article unread" : "Mantendu artikulua irakurri gabea",
    "Remove keep article unread" : "Ezabatu mantendu artikulua irakurri gabea",
    "by" : " Egilea:",
    "from" : "lekua",
    "Download video" : "Deskargatu bideoa",
    "Keyboard shortcut" : "Teklatuko lasterbidea",
    "Description" : "Deskribapena",
    "right" : "eskuina",
    "Jump to next article" : "Joan hurrengo lasterbidera",
    "left" : "ezkerra",
    "Jump to previous article" : "Joan aurreko artikulura",
    "Open article in new tab" : "Ireki artikulua fitxa berri batean",
    "Refresh" : "Birkargatu",
    "Load next feed" : "Kargatu hurrengo iturburu jarioa",
    "Load previous feed" : "Kargatu aurreko iturburu jarioa",
    "Load next folder" : "Kargatu hurrengo karpeta",
    "Load previous folder" : "Kargatu aurreko karpeta",
    "Web address" : "Web helbidea",
    "Feed exists already!" : "Iturburua dagoeneko existitzen da!",
    "Folder" : "Karpeta",
    "No folder" : "Karpetarik ez",
    "New folder" : "Karpeta berria",
    "Folder name" : "Karpetaren izena",
    "Go back" : "Atzera",
    "Folder exists already!" : "Karpeta dagoeneko existitzen da!",
    "Credentials" : "Kredentzialak",
    "Username" : "Erabiltzaile izena",
    "Password" : "Pasahitza",
    "New Folder" : "Karpeta berria",
    "Create" : "Sortu",
    "Explore" : "Arakatu",
    "Deleted feed" : "Ezabatu iturburua",
    "Rename" : "Berrizendatu",
    "Menu" : "Menua",
    "Default order" : "Lehenetsitako ordena",
    "Open feed URL" : "Ireki jarioaren URLa",
    "Delete" : "Ezabatu",
    "Collapse" : "Tolestu",
    "Deleted folder" : "Ezabatu karpeta",
    "Starred" : "Izardunak",
    "Unread articles" : "Irakurri gabeko artikuluak",
    "All articles" : "Artikulu guztiak",
    "Settings" : "Ezarpenak",
    "Compact view" : "Ikuspegi konpaktua",
    "Show all articles" : "Erakutsi artikulu guztiak",
    "Subscriptions (OPML)" : "Harpidetzak (OPML)",
    "Import" : "Inportatu",
    "Export" : "Esportatu",
    "Unread/Starred Articles" : "Irakurri gabeko/markatutako artikuluak",
    "Error when importing: file does not contain valid JSON" : "Errorea inportatzean: fitxategiak ez du baliozko JSON",
    "Help" : "Laguntza",
    "Keyboard shortcuts" : "Teklatuaren lasterbideak",
    "Documentation" : "Dokumentazioa"
},
"nplurals=2; plural=(n != 1);");
